package com.jiuqi.util.chinese;

package .var.folders._j.vfbv187d0bb8b8w5spzgg8180000gn.T;

import com.jiuqi.util.chinese.NotValidChineseDigitUnitException;
import java.io.Serializable;

class ChineseDigitUnit implements Cloneable, Serializable {
  private static final char[] SMALL_UNIT = new char[] { '十', '百', '千' };
  
  private static final char[] BIG_UNIT = new char[] { '拾', '佰', '仟' };
  
  private static final char[] LARGE_UNIT = new char[] { '万', '亿' };
  
  private static String bufferedUnit = null;
  
  private static String bufferedPower = null;
  
  private String power;
  
  public ChineseDigitUnit() {
    this.power = "1";
  }
  
  public ChineseDigitUnit(long power) {
    if (power < 0L)
      power = -power; 
    long value = 1L;
    while (power >= 10L) {
      power /= 10L;
      value *= 10L;
    } 
    this.power = String.valueOf(value);
  }
  
  public ChineseDigitUnit(String unit) {
    if (unit != null && unit.equals("")) {
      boolean digitString = isDigitString(unit);
      if (digitString) {
        StringBuffer sb = new StringBuffer("1");
        for (int i = 0; i < unit.length() - 1; i++)
          sb.append("0"); 
        this.power = sb.toString();
      } else {
        try {
          this.power = valueOf(unit);
        } catch (NotValidChineseDigitUnitException notValidChineseDigitUnitException) {
          throw new IllegalArgumentException("单位\"" + unit + 
              "\"既不是一个有效的阿拉伯数字，也不是有效的中文数字单位！");
        } 
      } 
    } else {
      throw new IllegalArgumentException("字符串为null或者空字符串！");
    } 
  }
  
  public long longValue() {
    return Long.parseLong(this.power);
  }
  
  public String chineseValue(boolean useBigChar) {
    return toChineseUnit(this.power, useBigChar);
  }
  
  public static String valueOf(String value) throws NotValidChineseDigitUnitException {
    if (value.equals(bufferedUnit))
      return bufferedPower; 
    long result = 0L;
    for (int i = 0; i < value.length(); i++) {
      char thisUnit = value.charAt(i);
      int position = -1;
      int k;
      for (k = 0; k < SMALL_UNIT.length; k++) {
        if (thisUnit == SMALL_UNIT[k]) {
          position = k;
          break;
        } 
      } 
      if (position != -1) {
        result += (position + 1);
        position = -1;
      } else {
        for (k = 0; k < BIG_UNIT.length; k++) {
          if (thisUnit == BIG_UNIT[k]) {
            position = k;
            break;
          } 
        } 
        if (position != -1) {
          result += (position + 1);
          position = -1;
        } else {
          for (k = 0; k < LARGE_UNIT.length; k++) {
            if (thisUnit == LARGE_UNIT[k]) {
              position = k;
              break;
            } 
          } 
          if (position != -1) {
            result += (4 * (position + 1));
            position = -1;
          } else {
            throw new NotValidChineseDigitUnitException("字符" + thisUnit + "不是一个合法的中文数字单位！");
          } 
        } 
      } 
    } 
    StringBuffer sb = new StringBuffer("1");
    for (int j = 0; j < result; j++)
      sb.append("0"); 
    bufferedUnit = value;
    bufferedPower = sb.toString();
    return sb.toString();
  }
  
  public static String toChineseUnit(String power, boolean useBigChar) {
    if (isDigitString(power)) {
      int pow = power.length();
      StringBuffer sb = new StringBuffer();
      while (pow > 8) {
        sb.insert(0, LARGE_UNIT[1]);
        pow -= 8;
      } 
      while (pow > 4) {
        sb.insert(0, LARGE_UNIT[0]);
        pow -= 4;
      } 
      if (pow > 1)
        if (!useBigChar) {
          sb.insert(0, SMALL_UNIT[pow - 2]);
        } else {
          sb.insert(0, BIG_UNIT[pow - 2]);
        }  
      return sb.toString();
    } 
    throw new IllegalArgumentException("字符串\"" + power + "\"不是一个阿拉伯数字字符串！");
  }
  
  static boolean isDigitString(String value) {
    for (int i = 0; i < value.length(); i++) {
      char c = value.charAt(i);
      if (!Character.isDigit(c))
        return false; 
    } 
    return true;
  }
  
  public static boolean isValidChineseDigitUnit(String value) {
    try {
      valueOf(value);
      return true;
    } catch (NotValidChineseDigitUnitException notValidChineseDigitUnitException) {
      return false;
    } 
  }
  
  public static boolean isLargeUnit(char value) {
    for (int i = 0; i < LARGE_UNIT.length; i++) {
      if (value == LARGE_UNIT[i])
        return true; 
    } 
    return false;
  }
  
  public Object clone() {
    return new com.jiuqi.util.chinese.ChineseDigitUnit(this.power);
  }
  
  public boolean equals(Object obj) {
    if (this == obj)
      return true; 
    if (!(obj instanceof com.jiuqi.util.chinese.ChineseDigitUnit))
      return false; 
    com.jiuqi.util.chinese.ChineseDigitUnit unit = (com.jiuqi.util.chinese.ChineseDigitUnit)obj;
    return this.power.equals(unit.power);
  }
  
  public int hashCode() {
    int value = super.hashCode();
    if (this.power != null)
      value ^= this.power.hashCode(); 
    return value;
  }
  
  public String toString() {
    return chineseValue(false);
  }
}
